@@ -9,6 +9,7 @@ import ujson
 import redis
 import random
 import socket
+import logging
 import tldextract
 from builtins import str
 from . import bhf_signals
@@ -230,7 +231,7 @@ class DistributedScheduler(object):
 
             if self.add_type:
                 throttle_key = self.spider.name + ":"
-            if self.add_ip:
+            if self.add_ip and self.my_ip is not None:
                 throttle_key = throttle_key + self.my_ip + ":"
 
             # add the tld from the key `type:tld:queue`
