@@ -1,6 +1,5 @@
 import asyncio
 import logging
-import warnings
 
 from time import time
 from .. import bhf_signals
@@ -26,7 +25,6 @@ from scrapy.utils.misc import load_object
 from scrapy.utils.python import to_unicode
 from scrapy.responsetypes import responsetypes
 from scrapy.utils.defer import deferred_from_coro
-from scrapy.exceptions import ScrapyDeprecationWarning
 from scrapy.utils.reactor import verify_installed_reactor
 from twisted.internet.defer import Deferred, inlineCallbacks
 from scrapy.core.downloader.handlers.http import HTTPDownloadHandler
@@ -169,7 +167,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             self.context_semaphores['default'].release()
         logger.info("Re create browser: Completed")
 
-    async def _create_page(self, request: Request) -> Page:
+    async def _create_page(self) -> Page:
         """Create a new page in a context, also creating a new context if necessary."""
         context = self.contexts.get("default")
 
@@ -223,7 +221,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             logger.info(f"[{request.url}] Before acquire")
             await self.context_semaphores['default'].acquire()
             logger.info(f"[{request.url}] After acquire")
-            page = await self._create_page(request)
+            page = await self._create_page()
 
             # attach event handlers
             event_handlers = request.meta.get("playwright_page_event_handlers") or {}
@@ -322,10 +320,12 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
                                 pgi.result = await result if isawaitable(result) else result
                                 await page.wait_for_load_state(timeout=self.default_navigation_timeout)
                                 return
-                            except TimeoutError:
+                            except Exception:
                                 timeouts += 1
                                 if timeouts == group_length:
                                     raise
+                                else:
+                                    logger.warning(f"Ignoring TimeoutError {timeouts} time")
             elif isinstance(pm, PageMethod):
                 result = _get_page_method_result(page, pm)
                 if result is not None:
